@@ -107,8 +107,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from ._jsii import *
 
@@ -125,7 +125,7 @@ class IotToLambda(
     def __init__(
         self,
         scope: aws_cdk.core.Construct,
-        id: str,
+        id: builtins.str,
         *,
         iot_topic_rule_props: aws_cdk.aws_iot.CfnTopicRuleProps,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
@@ -153,12 +153,12 @@ class IotToLambda(
 
         jsii.create(IotToLambda, self, [scope, id, props])
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="iotTopicRule")
     def iot_topic_rule(self) -> aws_cdk.aws_iot.CfnTopicRule:
         return jsii.get(self, "iotTopicRule")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="lambdaFunction")
     def lambda_function(self) -> aws_cdk.aws_lambda.Function:
         return jsii.get(self, "lambdaFunction")
@@ -193,7 +193,7 @@ class IotToLambdaProps:
             iot_topic_rule_props = aws_cdk.aws_iot.CfnTopicRuleProps(**iot_topic_rule_props)
         if isinstance(lambda_function_props, dict):
             lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "iot_topic_rule_props": iot_topic_rule_props,
         }
         if existing_lambda_obj is not None:
@@ -208,7 +208,9 @@ class IotToLambdaProps:
         default
         :default: - None
         """
-        return self._values.get("iot_topic_rule_props")
+        result = self._values.get("iot_topic_rule_props")
+        assert result is not None, "Required property 'iot_topic_rule_props' is missing"
+        return result
 
     @builtins.property
     def existing_lambda_obj(self) -> typing.Optional[aws_cdk.aws_lambda.Function]:
@@ -217,7 +219,8 @@ class IotToLambdaProps:
         default
         :default: - None
         """
-        return self._values.get("existing_lambda_obj")
+        result = self._values.get("existing_lambda_obj")
+        return result
 
     @builtins.property
     def lambda_function_props(
@@ -228,12 +231,13 @@ class IotToLambdaProps:
         default
         :default: - Default props are used
         """
-        return self._values.get("lambda_function_props")
+        result = self._values.get("lambda_function_props")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
